@@ -6,8 +6,8 @@ import (
 	"strings"
 
 	"github.com/cli/cli/v2/internal/ghinstance"
-	ghAuth "github.com/cli/go-gh/pkg/auth"
-	"github.com/cli/go-gh/pkg/repository"
+	ghauth "github.com/cli/go-gh/v2/pkg/auth"
+	"github.com/cli/go-gh/v2/pkg/repository"
 )
 
 // Interface describes an object that represents a GitHub repository
@@ -37,7 +37,7 @@ func FullName(r Interface) string {
 }
 
 func defaultHost() string {
-	host, _ := ghAuth.DefaultHost()
+	host, _ := ghauth.DefaultHost()
 	return host
 }
 
@@ -50,11 +50,11 @@ func FromFullName(nwo string) (Interface, error) {
 // FromFullNameWithHost is like FromFullName that defaults to a specific host for values that don't
 // explicitly include a hostname.
 func FromFullNameWithHost(nwo, fallbackHost string) (Interface, error) {
-	repo, err := repository.ParseWithHost(nwo, defaultHost())
+	repo, err := repository.ParseWithHost(nwo, fallbackHost)
 	if err != nil {
 		return nil, err
 	}
-	return NewWithHost(repo.Owner(), repo.Name(), repo.Host()), nil
+	return NewWithHost(repo.Owner, repo.Name, repo.Host), nil
 }
 
 // FromURL extracts the GitHub repository information from a git remote URL
@@ -92,12 +92,13 @@ func GenerateRepoURL(repo Interface, p string, args ...interface{}) string {
 	return baseURL
 }
 
-// TODO there is a parallel implementation for non-isolated commands
 func FormatRemoteURL(repo Interface, protocol string) string {
 	if protocol == "ssh" {
+		if tenant, found := ghinstance.TenantName(repo.RepoHost()); found {
+			return fmt.Sprintf("%s@%s:%s/%s.git", tenant, repo.RepoHost(), repo.RepoOwner(), repo.RepoName())
+		}
 		return fmt.Sprintf("git@%s:%s/%s.git", repo.RepoHost(), repo.RepoOwner(), repo.RepoName())
 	}
-
 	return fmt.Sprintf("%s%s/%s.git", ghinstance.HostPrefix(repo.RepoHost()), repo.RepoOwner(), repo.RepoName())
 }
 
