@@ -2,6 +2,7 @@ package comment
 
 import (
 	"bytes"
+	"errors"
 	"fmt"
 	"net/http"
 	"os"
@@ -31,11 +32,13 @@ func TestNewCmdComment(t *testing.T) {
 		stdin    string
 		output   shared.CommentableOptions
 		wantsErr bool
+		isTTY    bool
 	}{
 		{
 			name:     "no arguments",
 			input:    "",
 			output:   shared.CommentableOptions{},
+			isTTY:    true,
 			wantsErr: true,
 		},
 		{
@@ -46,6 +49,7 @@ func TestNewCmdComment(t *testing.T) {
 				InputType:   0,
 				Body:        "",
 			},
+			isTTY:    true,
 			wantsErr: false,
 		},
 		{
@@ -56,6 +60,7 @@ func TestNewCmdComment(t *testing.T) {
 				InputType:   0,
 				Body:        "",
 			},
+			isTTY:    true,
 			wantsErr: false,
 		},
 		{
@@ -66,6 +71,7 @@ func TestNewCmdComment(t *testing.T) {
 				InputType:   shared.InputTypeInline,
 				Body:        "test",
 			},
+			isTTY:    true,
 			wantsErr: false,
 		},
 		{
@@ -77,6 +83,7 @@ func TestNewCmdComment(t *testing.T) {
 				InputType:   shared.InputTypeInline,
 				Body:        "this is on standard input",
 			},
+			isTTY:    true,
 			wantsErr: false,
 		},
 		{
@@ -87,6 +94,7 @@ func TestNewCmdComment(t *testing.T) {
 				InputType:   shared.InputTypeInline,
 				Body:        "a body from file",
 			},
+			isTTY:    true,
 			wantsErr: false,
 		},
 		{
@@ -97,6 +105,7 @@ func TestNewCmdComment(t *testing.T) {
 				InputType:   shared.InputTypeEditor,
 				Body:        "",
 			},
+			isTTY:    true,
 			wantsErr: false,
 		},
 		{
@@ -107,6 +116,7 @@ func TestNewCmdComment(t *testing.T) {
 				InputType:   shared.InputTypeWeb,
 				Body:        "",
 			},
+			isTTY:    true,
 			wantsErr: false,
 		},
 		{
@@ -118,6 +128,7 @@ func TestNewCmdComment(t *testing.T) {
 				Body:        "",
 				EditLast:    true,
 			},
+			isTTY:    true,
 			wantsErr: false,
 		},
 		{
@@ -130,42 +141,110 @@ func TestNewCmdComment(t *testing.T) {
 				EditLast:     true,
 				CreateIfNone: true,
 			},
+			isTTY:    true,
 			wantsErr: false,
 		},
+		{
+			name:     "delete last flag non-interactive",
+			input:    "1 --delete-last",
+			isTTY:    false,
+			wantsErr: true,
+		},
+		{
+			name:  "delete last flag and pre-confirmation non-interactive",
+			input: "1 --delete-last --yes",
+			output: shared.CommentableOptions{
+				DeleteLast:          true,
+				DeleteLastConfirmed: true,
+			},
+			isTTY:    false,
+			wantsErr: false,
+		},
+		{
+			name:  "delete last flag interactive",
+			input: "1 --delete-last",
+			output: shared.CommentableOptions{
+				Interactive: true,
+				DeleteLast:  true,
+			},
+			isTTY:    true,
+			wantsErr: false,
+		},
+		{
+			name:  "delete last flag and pre-confirmation interactive",
+			input: "1 --delete-last --yes",
+			output: shared.CommentableOptions{
+				Interactive:         true,
+				DeleteLast:          true,
+				DeleteLastConfirmed: true,
+			},
+			isTTY:    true,
+			wantsErr: false,
+		},
+		{
+			name:     "delete last flag and pre-confirmation with web flag",
+			input:    "1 --delete-last --yes --web",
+			isTTY:    true,
+			wantsErr: true,
+		},
+		{
+			name:     "delete last flag and pre-confirmation with editor flag",
+			input:    "1 --delete-last --yes --editor",
+			isTTY:    true,
+			wantsErr: true,
+		},
+		{
+			name:     "delete last flag and pre-confirmation with body flag",
+			input:    "1 --delete-last --yes --body",
+			isTTY:    true,
+			wantsErr: true,
+		},
+		{
+			name:     "delete pre-confirmation without delete last flag",
+			input:    "1 --yes",
+			isTTY:    true,
+			wantsErr: true,
+		},
 		{
 			name:     "body and body-file flags",
 			input:    "1 --body 'test' --body-file 'test-file.txt'",
 			output:   shared.CommentableOptions{},
+			isTTY:    true,
 			wantsErr: true,
 		},
 		{
 			name:     "editor and web flags",
 			input:    "1 --editor --web",
 			output:   shared.CommentableOptions{},
+			isTTY:    true,
 			wantsErr: true,
 		},
 		{
 			name:     "editor and body flags",
 			input:    "1 --editor --body test",
 			output:   shared.CommentableOptions{},
+			isTTY:    true,
 			wantsErr: true,
 		},
 		{
 			name:     "web and body flags",
 			input:    "1 --web --body test",
 			output:   shared.CommentableOptions{},
+			isTTY:    true,
 			wantsErr: true,
 		},
 		{
 			name:     "editor, web, and body flags",
 			input:    "1 --editor --web --body test",
 			output:   shared.CommentableOptions{},
+			isTTY:    true,
 			wantsErr: true,
 		},
 		{
 			name:     "create-if-none flag without edit-last",
 			input:    "1 --create-if-none",
 			output:   shared.CommentableOptions{},
+			isTTY:    true,
 			wantsErr: true,
 		},
 	}
@@ -173,9 +252,10 @@ func TestNewCmdComment(t *testing.T) {
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
 			ios, stdin, _, _ := iostreams.Test()
-			ios.SetStdoutTTY(true)
-			ios.SetStdinTTY(true)
-			ios.SetStderrTTY(true)
+			isTTY := tt.isTTY
+			ios.SetStdoutTTY(isTTY)
+			ios.SetStdinTTY(isTTY)
+			ios.SetStderrTTY(isTTY)
 
 			if tt.stdin != "" {
 				_, _ = stdin.WriteString(tt.stdin)
@@ -211,6 +291,8 @@ func TestNewCmdComment(t *testing.T) {
 			assert.Equal(t, tt.output.Interactive, gotOpts.Interactive)
 			assert.Equal(t, tt.output.InputType, gotOpts.InputType)
 			assert.Equal(t, tt.output.Body, gotOpts.Body)
+			assert.Equal(t, tt.output.DeleteLast, gotOpts.DeleteLast)
+			assert.Equal(t, tt.output.DeleteLastConfirmed, gotOpts.DeleteLastConfirmed)
 		})
 	}
 }
@@ -220,6 +302,7 @@ func Test_commentRun(t *testing.T) {
 		name          string
 		input         *shared.CommentableOptions
 		emptyComments bool
+		comments      api.Comments
 		httpStubs     func(*testing.T, *httpmock.Registry)
 		stdout        string
 		stderr        string
@@ -255,6 +338,7 @@ func Test_commentRun(t *testing.T) {
 			},
 			emptyComments: true,
 			wantsErr:      true,
+			stdout:        "no comments found for current user",
 		},
 		{
 			name: "updating last comment with interactive editor succeeds if there are comments",
@@ -331,6 +415,7 @@ func Test_commentRun(t *testing.T) {
 			},
 			emptyComments: true,
 			wantsErr:      true,
+			stdout:        "no comments found for current user",
 		},
 		{
 			name: "creating new comment with non-interactive editor succeeds",
@@ -358,6 +443,7 @@ func Test_commentRun(t *testing.T) {
 			},
 			emptyComments: true,
 			wantsErr:      true,
+			stdout:        "no comments found for current user",
 		},
 		{
 			name: "updating last comment with non-interactive editor succeeds if there are comments",
@@ -433,6 +519,117 @@ func Test_commentRun(t *testing.T) {
 			},
 			stdout: "https://github.com/OWNER/REPO/issues/123#issuecomment-456\n",
 		},
+		{
+			name: "deleting last comment non-interactively without any comment",
+			input: &shared.CommentableOptions{
+				Interactive: false,
+				DeleteLast:  true,
+			},
+			emptyComments: true,
+			wantsErr:      true,
+			stdout:        "no comments found for current user",
+		},
+		{
+			name: "deleting last comment interactively without any comment",
+			input: &shared.CommentableOptions{
+				Interactive: true,
+				DeleteLast:  true,
+			},
+			emptyComments: true,
+			wantsErr:      true,
+			stdout:        "no comments found for current user",
+		},
+		{
+			name: "deleting last comment non-interactively and pre-confirmed",
+			input: &shared.CommentableOptions{
+				Interactive:         false,
+				DeleteLast:          true,
+				DeleteLastConfirmed: true,
+			},
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				mockCommentDelete(t, reg)
+			},
+			stderr: "Comment deleted\n",
+		},
+		{
+			name: "deleting last comment interactively and pre-confirmed",
+			input: &shared.CommentableOptions{
+				Interactive:         true,
+				DeleteLast:          true,
+				DeleteLastConfirmed: true,
+			},
+			comments: api.Comments{Nodes: []api.Comment{
+				{ID: "id1", Author: api.CommentAuthor{Login: "octocat"}, URL: "https://github.com/OWNER/REPO/pull/123#issuecomment-111", ViewerDidAuthor: true, Body: "comment body"},
+			}},
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				mockCommentDelete(t, reg)
+			},
+			stderr: "Comment deleted\n",
+		},
+		{
+			name: "deleting last comment interactively and confirmed",
+			input: &shared.CommentableOptions{
+				Interactive: true,
+				DeleteLast:  true,
+
+				ConfirmDeleteLastComment: func(body string) (bool, error) {
+					if body != "comment body" {
+						return false, errors.New("unexpected comment body")
+					}
+					return true, nil
+				},
+			},
+			comments: api.Comments{Nodes: []api.Comment{
+				{ID: "id1", Author: api.CommentAuthor{Login: "octocat"}, URL: "https://github.com/OWNER/REPO/pull/123#issuecomment-111", ViewerDidAuthor: true, Body: "comment body"},
+			}},
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				mockCommentDelete(t, reg)
+			},
+			stdout: "! Deleted comments cannot be recovered.\n",
+			stderr: "Comment deleted\n",
+		},
+		{
+			name: "deleting last comment interactively and confirmation declined",
+			input: &shared.CommentableOptions{
+				Interactive: true,
+				DeleteLast:  true,
+
+				ConfirmDeleteLastComment: func(body string) (bool, error) {
+					if body != "comment body" {
+						return false, errors.New("unexpected comment body")
+					}
+					return true, nil
+				},
+			},
+			comments: api.Comments{Nodes: []api.Comment{
+				{ID: "id1", Author: api.CommentAuthor{Login: "octocat"}, URL: "https://github.com/OWNER/REPO/pull/123#issuecomment-111", ViewerDidAuthor: true, Body: "comment body"},
+			}},
+			wantsErr: true,
+			stdout:   "deletion not confirmed",
+		},
+		{
+			name: "deleting last comment interactively and confirmed with long comment body",
+			input: &shared.CommentableOptions{
+				Interactive: true,
+				DeleteLast:  true,
+
+				ConfirmDeleteLastComment: func(body string) (bool, error) {
+					if body != "Lorem ipsum dolor sit amet, consectet lo..." {
+						return false, errors.New("unexpected comment body")
+					}
+					return true, nil
+				},
+			},
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				mockCommentDelete(t, reg)
+			},
+			comments: api.Comments{Nodes: []api.Comment{
+				{ID: "id1", Author: api.CommentAuthor{Login: "octocat"}, URL: "https://github.com/OWNER/REPO/pull/123#issuecomment-111", ViewerDidAuthor: true, Body: "Lorem ipsum dolor sit amet, consectet lorem ipsum again"},
+			}},
+			wantsErr: false,
+			stdout:   "! Deleted comments cannot be recovered.\n",
+			stderr:   "Comment deleted\n",
+		},
 	}
 	for _, tt := range tests {
 		ios, _, stdout, stderr := iostreams.Test()
@@ -458,6 +655,8 @@ func Test_commentRun(t *testing.T) {
 
 		if tt.emptyComments {
 			comments.Nodes = []api.Comment{}
+		} else if len(tt.comments.Nodes) > 0 {
+			comments = tt.comments
 		}
 
 		tt.input.RetrieveCommentable = func() (shared.Commentable, ghrepo.Interface, error) {
@@ -472,6 +671,7 @@ func Test_commentRun(t *testing.T) {
 			err := shared.CommentableRun(tt.input)
 			if tt.wantsErr {
 				assert.Error(t, err)
+				assert.Equal(t, tt.stderr, stderr.String())
 				return
 			}
 			assert.NoError(t, err)
@@ -508,3 +708,15 @@ func mockCommentUpdate(t *testing.T, reg *httpmock.Registry) {
 			}),
 	)
 }
+
+func mockCommentDelete(t *testing.T, reg *httpmock.Registry) {
+	reg.Register(
+		httpmock.GraphQL(`mutation CommentDelete\b`),
+		httpmock.GraphQLMutation(`
+		{ "data": { "deleteIssueComment": {} } }`,
+			func(inputs map[string]interface{}) {
+				assert.Equal(t, "id1", inputs["id"])
+			},
+		),
+	)
+}
